# Chapter 1: Quantitative Investment Overview and Environment Setup

This chapter is currently maintained in Chinese first.

- Chinese chapter: [第 1 章：量化投资概述与环境搭建](../../zh/textbook/01_foundations.md)
- Textbook home: [Chinese textbook index](../../zh/textbook/index.md)
- Practice links:
  - Primary example: [examples/textbook/ch01_quickstart.py](https://github.com/akfamily/akquant/blob/main/examples/textbook/ch01_quickstart.py)
  - Extended example: [examples/01_quickstart.py](https://github.com/akfamily/akquant/blob/main/examples/01_quickstart.py)
  - Guide: [Quickstart Guide](../start/quickstart.md)
